@@ -47,23 +47,39 @@ test_that("Dictionary throws exception on unnamed args", {
   expect_error(x$mget("a", "b"), "names")
 })
 
-test_that("dictionary_sugar", {
+test_that("dictionary_sugar_get", {
   Foo = R6::R6Class("Foo", public = list(x = 0, y = 0, key = 0, initialize = function(y, key = -1) { self$y = y ; self$key = key }), cloneable = TRUE)
   d = Dictionary$new()
   d$add("f1", Foo)
-  x = dictionary_sugar(d, "f1", y = 99, x = 1)
+  x = dictionary_sugar_get(d, "f1", y = 99, x = 1)
   expect_equal(x$x, 1)
   expect_equal(x$y, 99)
   expect_equal(x$key, -1)
-  x2 = dictionary_sugar(d, "f1", 99, x = 1)
+  x2 = dictionary_sugar_get(d, "f1", 99, x = 1)
   expect_equal(x, x2)
-  x2 = dictionary_sugar(d, "f1", x = 1, 99)
+  x2 = dictionary_sugar_get(d, "f1", x = 1, 99)
   expect_equal(x, x2)
 
-  x = dictionary_sugar(d, "f1", 1, 99)
+  x = dictionary_sugar_get(d, "f1", 1, 99)
   expect_equal(x$x, 0)
   expect_equal(x$y, 1)
   expect_equal(x$key, 99)
-  x2 = dictionary_sugar(d, "f1", key = 99, y = 1)
+  x2 = dictionary_sugar_get(d, "f1", key = 99, y = 1)
   expect_equal(x, x2)
 })
+
+test_that("mget", {
+  Foo = R6::R6Class("Foo", public = list(id = "foo", x = 0, y = 0, key = 0, initialize = function(y, key = -1) { self$y = y ; self$key = key }), cloneable = TRUE)
+  d = Dictionary$new()
+  d$add("f1", Foo)
+  d$add("f2", Foo)
+  x = dictionary_sugar_mget(d, "f1", y = 99, x = 1)
+  expect_list(x, len = 1, types = "Foo")
+  x = dictionary_sugar_mget(d, c("f1", "f2"), y = 99)
+  expect_list(x, len = 2, types = "Foo")
+  expect_equal(ids(x), c("foo", "foo"))
+
+  x = dictionary_sugar_mget(d, c(a = "f1", b = "f2"), y = 99)
+  expect_list(x, len = 2, types = "Foo")
+  expect_equal(ids(x), c("a", "b"))
+})
